0.9.9 API documentation: vector_int2_precision.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

vector_int2_precision.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_vec2.hpp"
6
7 namespace glm
8 {
11
16 typedef vec<2, int, highp> highp_ivec2;
17
22 typedef vec<2, int, mediump> mediump_ivec2;
23
28 typedef vec<2, int, lowp> lowp_ivec2;
29
31 }//namespace glm
glm::highp_ivec2
vec< 2, int, highp > highp_ivec2
2 components vector of high qualifier signed integer numbers.
Definition: vector_int2_precision.hpp:16
glm::mediump_ivec2
vec< 2, int, mediump > mediump_ivec2
2 components vector of medium qualifier signed integer numbers.
Definition: vector_int2_precision.hpp:22
glm::lowp_ivec2
vec< 2, int, lowp > lowp_ivec2
2 components vector of low qualifier signed integer numbers.
Definition: vector_int2_precision.hpp:28
glm
Definition: common.hpp:20